@@ -1,13 +1,16 @@
 package Taskwarrior::Kusarigama::App::Add;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: Add plugins to Taskwarrior
-$Taskwarrior::Kusarigama::App::Add::VERSION = '0.4.0';
+$Taskwarrior::Kusarigama::App::Add::VERSION = '0.5.0';
+
 use 5.10.0;
 
 use strict;
 use warnings;
 
 use List::AllUtils qw/ uniq /;
+use Set::Object qw/ set /;
+use Module::Runtime qw/ use_module /;
 
 use Taskwarrior::Kusarigama;
 
@@ -21,11 +24,21 @@ extends 'Taskwarrior::Kusarigama::App';
 sub run {
     my $self = shift;
 
-    my @plugins = uniq( ( map { $_->name } $self->tw->plugins->@* ), $self->extra_argv->@* );
+    my $old_plugins = set( map { $_->name } $self->tw->plugins->@* );
 
-    say "setting plugins to ", join ', ', @plugins;
+    my $new_plugins = set($self->extra_argv->@*) - $old_plugins;
+
+    my $plugins = $old_plugins + $new_plugins;
+
+    say "setting plugins to ", join ', ', @$plugins;
+
+    $self->tw->run_task->config( [{ 'rc.confirmation' => 'off' }], 'kusarigama.plugins', join ',', @$plugins );
+
+    $_->new( tw => $self->tw )->setup for
+        grep { use_module($_)->can('setup') } 
+        map { "Taskwarrior::Kusarigama::Plugin::$_" }
+            @$new_plugins;
 
-    system 'task', 'config', 'kusarigama.plugins', join ',', @plugins;
 }
 
 1;
@@ -42,7 +55,11 @@ Taskwarrior::Kusarigama::App::Add - Add plugins to Taskwarrior
 
 =head1 VERSION
 
-version 0.4.0
+version 0.5.0
+
+=head1 SYNOPSIS
+
+    $ task-kusarigama add Command::Open Renew
 
 =head1 AUTHOR
 
